==> php54-owncloud-8.0.2.tgz: share/owncloud/apps/activity/l10n/sv.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivitet",
    "Your settings have been updated." : "Dina inställningar har uppdaterats.",
    "A file or folder has been <strong>shared</strong>" : "En fil eller mapp har <strong>delats</strong>",
    "A new file or folder has been <strong>created</strong>" : "En ny fil eller mapp har blivit <strong>skapad</strong>",
    "A file or folder has been <strong>changed</strong>" : "En ny fil eller mapp har blivit <strong>ändrad</strong>",
    "A file or folder has been <strong>deleted</strong>" : "En ny fil eller mapp har blivit <strong>raderad</strong>",
    "A file or folder has been <strong>restored</strong>" : "En ny fil eller mapp har blivit <strong>återskapad</strong>",
    "You created %1$s" : "Du skapade %1$s",
    "%2$s created %1$s" : "%2$s skapade %1$s",
    "%1$s was created in a public folder" : "%1$s skapades i en publik mapp",
    "You changed %1$s" : "Du ändrade %1$s",
    "%2$s changed %1$s" : "%2$s ändrade %1$s",
    "You deleted %1$s" : "Du raderade %1$s",
    "%2$s deleted %1$s" : "%2$s raderade %1$s",
    "You restored %1$s" : "Du återkapade %1$s",
    "%2$s restored %1$s" : "%2$s återskapade %1$s",
    "You shared %1$s with %2$s" : "Du delade %1$s med %2$s",
    "You shared %1$s with group %2$s" : "Du delade %1$s med grupp %2$s",
    "%2$s shared %1$s with you" : "%2$s delade %1$s med dig",
    "You shared %1$s via link" : "Du delade %1$s via länk",
    "Activity notification" : "Aktivitet notifiering",
    "All Activities" : "Alla aktiviteter",
    "Activities by you" : "Aktivitet av dig",
    "Activities by others" : "Aktiviteter av andra",
    "Shares" : "Delningar",
    "Files" : "Filer",
    "in %s" : "in %s",
    "%s and %s" : "%s och %s",
    ", " : ",",
    "%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>::%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>" : ["%s och <strong class=\"tooltip\" title=\"%s\">%n mer</strong>","%s och <strong class=\"tooltip\" title=\"%s\">%n mer</strong>"],
    "%s and %n more::%s and %n more" : ["%s och %n mer","%s och %n mer"],
    "Hello %s," : "Hej %s,",
    "You are receiving this email because in the last hour the following things happened at %s" : "Du har fått detta e-postmeddelande på grund av att under den senaste timmen har följande hänt på %s",
    "You are receiving this email because in the last day the following things happened at %s" : "Du har fått detta e-postmeddelande på grund av att under det senaste dygnet har följande hänt på %s",
    "You are receiving this email because in the last week the following things happened at %s" : "Du har fått detta e-postmeddelande på grund av att under den senaste veckan har följande hänt på %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "You will see a list of events here when you start to use your %s." : "Du kommer att se en lista utav evenemang här när du börjar använda din %s",
    "No more events to load" : "Inga fler aktiviteter att ladda.",
    "Enable RSS feed" : "Aktivera RSS-flöde",
    "Notifications" : "Notifieringar",
    "Mail" : "Post",
    "Stream" : "Ström",
    "List your own actions in the stream" : "Visa dina egna handlingar i flödet",
    "Notify about your own actions via email" : "Skicka notifieringsmail gällande dina egna handlingar",
    "You need to set up your email address before you can receive notification emails." : "Du måste ställa in din e-postadress innan du kan ta emot e-postmeddelanden.",
    "Send emails:" : "Skicka e-post:",
    "Hourly" : "Timme",
    "Daily" : "Dagligen",
    "Weekly" : "Varje vecka",
    "Activity feed" : "Aktivitetsflöde",
    "Personal activity feed for %s" : "Personligt aktivitetsflöde för %s"
},
"nplurals=2; plural=(n != 1);");

==> php54-owncloud-8.1.0.tgz: share/owncloud/apps/activity/l10n/sv.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivitet",
    "Personal activity feed for %s" : "Personligt aktivitetsflöde för %s",
    "Your settings have been updated." : "Dina inställningar har uppdaterats.",
    "Activity notification" : "Aktivitet notifiering",
    "All Activities" : "Alla aktiviteter",
    "Activities by you" : "Aktivitet av dig",
    "Activities by others" : "Aktiviteter av andra",
    "in %s" : "in %s",
    "%s and %s" : "%s och %s",
    ", " : ",",
    "_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_" : ["%s och <strong class=\"tooltip\" title=\"%s\">%n mer</strong>","%s och <strong class=\"tooltip\" title=\"%s\">%n mer</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s och %n mer","%s och %n mer"],
    "Hello %s," : "Hej %s,",
    "You are receiving this email because in the last hour the following things happened at %s" : "Du har fått detta e-postmeddelande på grund av att under den senaste timmen har följande hänt på %s",
    "You are receiving this email because in the last day the following things happened at %s" : "Du har fått detta e-postmeddelande på grund av att under det senaste dygnet har följande hänt på %s",
    "You are receiving this email because in the last week the following things happened at %s" : "Du har fått detta e-postmeddelande på grund av att under den senaste veckan har följande hänt på %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "Notifications" : "Notifieringar",
    "Mail" : "Post",
    "Stream" : "Ström",
    "List your own actions in the stream" : "Visa dina egna handlingar i flödet",
    "Notify about your own actions via email" : "Skicka notifieringsmail gällande dina egna handlingar",
    "You need to set up your email address before you can receive notification emails." : "Du måste ställa in din e-postadress innan du kan ta emot e-postmeddelanden.",
    "Send emails:" : "Skicka e-post:",
    "Hourly" : "Timme",
    "Daily" : "Dagligen",
    "Weekly" : "Varje vecka",
    "Activity feed" : "Aktivitetsflöde",
    "Enable RSS feed" : "Aktivera RSS-flöde",
    "No more events to load" : "Inga fler aktiviteter att ladda.",
    "Files" : "Filer"
},
"nplurals=2; plural=(n != 1);");
